#ifndef STRINGFILE_H
#define STRINGFILE_H

class Iff;
class String;
class Translator;

//---------------------------------------------

class StringFile
{
	friend Translator;

public:

//---------------------------------------------

	struct StringBattery
	{
		char *filename;
		int   numStrings;
		int   refCount;                // number of current users referencing this
		int   access;                  // total number of constructors using this since it was loaded
		int   languageId;              // index into langTable for this language
		int   maxUniqueId;             // total number of strings ever added to this file

		int     *uniqueIds;            // unique ID of the string used.  THESE ARE PARALLEL ARRAYS.
		String **strings;              // string itself.

		StringBattery *next;
	};

//---------------------------------------------

	struct LanguageInfo
	{
		char *directory;
		int  charsize;
	};

//---------------------------------------------

protected:
	static StringBattery *lpList;  // linked list held by the partition "manager"
	static LanguageInfo   langTable[];
	static int            languageTableCount;

	StringBattery *data;           // pointer to member in the linked list... no partition owns its own data.

	void load_0001(Iff *iff);

public:
	static void install(void);
	static void remove(void);

	explicit StringFile(const char *fn);
	~StringFile(void);

	int getNumStrings(void) const;

	const String &getStringById(int id) const;
	const String &getStringByIndex(int index) const;
};

//---------------------------------------------

inline int StringFile::getNumStrings(void) const
{
	return data->numStrings;
}

#endif
